Latest changes 
--------------

* table of `all latest changes`_
* table of `latest published packages`_

Links below are providing useful RQL queries examples.

.. _all latest changes: /view?rql=Any+M%2CX+WHERE+X+modification_date+M+ORDERBY+M+DESC+LIMIT+30
.. _latest published packages:  view?rql=Any+M%2CP%2CE+WHERE+E+is+Version%2C+E+publication_date+M%2C+E+in_state+S%2C+S+name+%27published%27%2C+E+version_of+P+ORDERBY+M+DESC 
